@@ -5,20 +5,15 @@
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-
-#ifndef KIG_IFACE_H
-#define KIG_IFACE_H
+#pragma once
 
 #include <dcopobject.h>
 
 class KigIface : virtual public DCOPObject
 {
-  K_DCOP
+    K_DCOP
 public:
-  KigIface();
-  ~KigIface();
-k_dcop:
-  virtual void openUrl(const QString& s) = 0;
+    KigIface();
+    ~KigIface();
+    k_dcop : virtual void openUrl(const QString &s) = 0;
 };
-
-#endif
